# general info
NAME="grub-bios"
DESC="GNU GRand Unified Bootloader"
VERSION="2.12"

# required files
FILES=(
  "https://ftp.gnu.org/gnu/grub/grub-${VERSION}.tar.xz"
  "https://unifoundry.com/pub/unifont/unifont-15.1.04/font-builds/unifont-15.1.04.pcf.gz"
  "default"
)
HASHES=(
  "60c564b1bdc39d8e43b3aab4bc0fb140"
  "72f95e7ecb47a4c7ed610babe6959ead"
  "80d333049c9524e0021f14fee0d515aee6d3aa00951021cfed2bb7c1b6e7437d"
)
KEEP=("/etc/default/grub")

# install and build depends
DEPENDS=(
  "gettext" "make" "xz"
  "make" "bash" "efibootmgr"
)
BUILD=("python3")

PACKAGE(){
  mkdir -pv "${ROOTDIR}/usr/share/fonts/unifont"
  gunzip -c unifont-15.1.04.pcf.gz > "${ROOTDIR}/usr/share/fonts/unifont/unifont.pcf"

  tar xf "grub-${VERSION}.tar.xz"
  cd "grub-${VERSION}"

  echo depends bli part_gpt > grub-core/extra_deps.lst
  ./configure --prefix=/usr        \
              --sysconfdir=/etc    \
              --with-bootdir=/boot \
              --disable-efiemu     \
              --enable-grub-mkfont \
              --enable-boot-time   \
              --with-platform=efi  \
              --with-grubdir=grub  \
              --target=x86_64      \
              --disable-werror

  # optimizations may cause issues with the bootloader
  CFLAGS="$(echo "${CFLAGS}" | sed 's/-O3//g' | sed 's/-O2//g')"

  make
  make DESTDIR="${ROOTDIR}" install

  install -dm755 "${ROOTDIR}/usr/share/bash-completion/completions"
  install -dm755 "${ROOTDIR}/etc/default"

  mv -v "${ROOTDIR}/etc/bash_completion.d/grub" "${ROOTDIR}/usr/share/bash-completion/completions"
  install -m644 "${ROOTDIR}/default" "${ROOTDIR}/etc/default/grub"

  cd .. && rm -r "grub-${VERSION}"
}
